@@ -28,13 +28,13 @@ CONTAINS
   
   IMPLICIT NONE
 
-#ifdef __PARA
+#ifdef __MPI
   CALL mp_startup()
 #endif
   
   CALL environment_start ( code )
   
-#ifdef __PARA
+#ifdef __MPI
   if(ionode) then
      write(stdout,*) 'MPI PARALLEL VERSION'
      write(stdout,*) 'Number of procs: ', nproc
@@ -55,7 +55,7 @@ CONTAINS
 
     IMPLICIT NONE
 
-#ifdef __PARA
+#ifdef __MPI
 
     if(ionode) write(stdout,*) 'Stopping MPI environment'
     call mp_global_end( )
