@@ -109,7 +109,7 @@ MODULE exchange_custom
       INTEGER :: offset
 
       !write(stdout,*) 'periodic_fock'
-      !call flush_unit(stdout)
+      !FLUSH(stdout)
     
       CALL start_clock('periodic_fock')
    
@@ -431,7 +431,7 @@ MODULE exchange_custom
                         enddo
                      else
                         write(stdout,*) 'to be implmented yet'
-                        call flush_unit(stdout)
+                        FLUSH(stdout)
                         stop
                      endif
                      CALL stop_clock('pf_product')
@@ -1107,7 +1107,7 @@ MODULE exchange_custom
          call mp_sum(sca,world_comm)
          sca=sca/dble(exx_cus%fft_g2r%nr1t*exx_cus%fft_g2r%nr2t*exx_cus%fft_g2r%nr3t)
          write(stdout,*) 'PERIODIC EXCHANGE', iv, sca
-         call flush_unit(stdout)
+         FLUSH(stdout)
       !end loop
       enddo
       deallocate(r2s_xy,r2s_z)
@@ -1128,7 +1128,8 @@ MODULE exchange_custom
 
 
       USE io_global,  ONLY : stdout, ionode, ionode_id
-      USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx, ecutwfc
+      USE wvfct,    ONLY : igk, npwx, npw, nbnd
+      USE gvecw, ONLY : ecutwfc
       USE cell_base, ONLY: at, alat, tpiba, omega, tpiba2,bg
       USE constants, ONLY : e2, pi, tpi, fpi, RYTOEV
       USE wavefunctions_module, ONLY : psic
@@ -1181,18 +1182,18 @@ MODULE exchange_custom
       exx_cus%fft_g2r%dual_t=dual
       call mp_barrier( world_comm )
       write(stdout,*) 'Before initialize_fft_custom',exx_cus%fft_g2r%ecutt,exx_cus%fft_g2r%dual_t
-      call flush_unit(stdout)
+      FLUSH(stdout)
       call initialize_fft_custom(exx_cus%fft_g2r)
       write(stdout,*) "GRID G to R", exx_cus%fft_g2r%nr1t, exx_cus%fft_g2r%nr2t, exx_cus%fft_g2r%nr3t
       write(stdout,*) "GRID G to R",exx_cus%fft_g2r%npwt
-      call flush_unit(stdout)
+      FLUSH(stdout)
 
       exx_cus%fft_r2g%ecutt=cutoff
       exx_cus%fft_r2g%dual_t=ecutwfc*dual/cutoff
       call initialize_fft_custom(exx_cus%fft_r2g)
       write(stdout,*) "GRID R to G", exx_cus%fft_r2g%nr1t, exx_cus%fft_r2g%nr2t, exx_cus%fft_r2g%nr3t
       write(stdout,*) "GRID R to G",exx_cus%fft_r2g%npwt
-      call flush_unit(stdout)
+      FLUSH(stdout)
       
       if(l_exchange_turbo) then
   !setup small grid
@@ -1464,7 +1465,7 @@ MODULE exchange_custom
 !apply Fock operator to a wavefunction
 
       USE io_global, ONLY : stdout, ionode, ionode_id
-      USE wvfct,     ONLY : igk, g2kin, npwx, npw, nbnd, nbndx, ecutwfc
+      USE wvfct,     ONLY : igk, npwx, npw, nbnd
       USE cell_base, ONLY: at, alat, tpiba, omega, tpiba2,bg
       USE constants, ONLY : e2, pi, tpi, fpi, RYTOEV
       USE wavefunctions_module, ONLY : psic
@@ -1656,7 +1657,7 @@ MODULE exchange_custom
 
     FUNCTION exchange_energy_fast(exx_cus,exxalpha)
 
-      USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx, ecutwfc
+      USE wvfct,    ONLY : igk, npwx, npw, nbnd
       USE wavefunctions_module, ONLY : evc
       USE mp, ONLY : mp_sum
       USE mp_world, ONLY : world_comm
@@ -1706,7 +1707,7 @@ MODULE exchange_custom
 
     subroutine dft_exchange_fast(ispin,nbnd_s,psi,exx_cus)
       USE io_global,            ONLY : stdout, ionode, ionode_id
-      USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx, ecutwfc,wg
+      USE wvfct,    ONLY : igk, npwx, npw, nbnd, wg
       USE gvect
       USE mp, ONLY : mp_sum
       USE mp_world, ONLY : world_comm
@@ -1744,7 +1745,7 @@ MODULE exchange_custom
          call mp_sum(sca,world_comm)
          write(stdout,*) 'EXCHANGE FAST',ii, sca
       enddo
-      call flush_unit(stdout)
+      FLUSH(stdout)
       deallocate(xpsi)
       return
     end subroutine dft_exchange_fast
