@@ -73,7 +73,7 @@ CONTAINS
   !     given as input parameters. Input values are kept otherwise.
   !
   USE io_global,  ONLY : stdout
-  use fft_scalar, only: allowed
+  use fft_support, only: allowed
   USE fft_base,             ONLY : dfftp
   implicit none
 
@@ -176,7 +176,7 @@ CONTAINS
                          inter_pool_comm,root_pool
   USE mp_world,   ONLY : world_comm, nproc
   USE stick_base
-  USE fft_scalar, ONLY : good_fft_dimension
+  USE fft_support, ONLY : good_fft_dimension
   USE fft_types,  ONLY : fft_dlay_allocate, fft_dlay_set, fft_dlay_scalar
   !
   !
@@ -203,7 +203,7 @@ CONTAINS
   INTEGER  :: ncplane, nxx
   INTEGER  :: ncplanes, nxxs
 
-#ifdef __PARA
+#ifdef __MPI
   INTEGER, ALLOCATABLE :: st(:,:), sts(:,:)
   ! sticks maps
 
@@ -229,7 +229,7 @@ CONTAINS
 
   call mp_barrier( world_comm )
   write(stdout,*) 'ATT1.0'
-  call flush_unit(stdout)
+  FLUSH(stdout)
   
   
   tk = .false.
@@ -247,7 +247,7 @@ CONTAINS
   ncplanes = fc%nrx1t * fc%nrx2t
   call mp_barrier( world_comm )
   write(stdout,*) 'ATT1.1'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   !
   ! check the number of plane per process
@@ -266,7 +266,7 @@ CONTAINS
   !
   call mp_barrier( world_comm )
   write(stdout,*) 'ATT1.2'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   n1 = fc%nr1t + 1
   n2 = fc%nr2t + 1
@@ -287,12 +287,12 @@ CONTAINS
 !
   call mp_barrier( world_comm )
   write(stdout,*) 'ATT1.3'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   CALL sticks_maps( tk, ub, lb, fc%bg_t(:,1), fc%bg_t(:,2), fc%bg_t(:,3), fc%gcutmt, gkcut, fc%gcutmt, st, &
        &stw, sts ,me_pool,nproc_pool,intra_pool_comm)
   write(stdout,*) 'ATT1.3.1'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   
   nct  = count( st  > 0 )
@@ -324,7 +324,7 @@ CONTAINS
 ! ...     ncts counts columns contaning G-vectors for the smooth grid
 !
   write(stdout,*) 'ATT1.5'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
 
   CALL sticks_countg( tk, ub, lb, st, stw, sts, in1, in2, ngc, ngkc, ngcs )
@@ -332,13 +332,13 @@ CONTAINS
   CALL sticks_sort( ngc, ngkc, ngcs, nct, idx ,nproc_pool)
 
   CALL sticks_dist( tk, ub, lb, idx, in1, in2, ngc, ngkc, ngcs, nct, &
-          ncp, nkcp, ncps, ngp, ngkp, ngps, st, stw, sts ,nproc_pool)
+          ncp, nkcp, ncps, ngp, ngkp, ngps, st, stw, sts , me_pool, nproc_pool)
 
   CALL sticks_pairup( tk, ub, lb, idx, in1, in2, ngc, ngkc, ngcs, nct, &
           ncp, nkcp, ncps, ngp, ngkp, ngps, st, stw, sts ,nproc_pool)
 
   write(stdout,*) 'ATT1.6'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   !  set the total number of G vectors
 
@@ -595,23 +595,23 @@ SUBROUTINE initialize_fft_custom(fc)
 
   call mp_barrier( world_comm )
   write(stdout,*) 'ATT1'
-  call flush_unit(stdout)
+  FLUSH(stdout)
   call  set_custom_grid(fc)
 
   call mp_barrier( world_comm )
   write(stdout,*) 'ATT2'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   call data_structure_custom(fc)
 
   call mp_barrier( world_comm )
   write(stdout,*) 'ATT3'
-  call flush_unit(stdout)
+  FLUSH(stdout)
   
   allocate(fc%nlt(fc%ngmt))
   allocate(fc%nltm(fc%ngmt))
   write(stdout,*) 'ATT4'
-  call flush_unit(stdout)
+  FLUSH(stdout)
   
   call ggent(fc)
   
@@ -648,23 +648,23 @@ SUBROUTINE initialize_fft_custom_cell(fc)
 
   call mp_barrier( world_comm )
   write(stdout,*) 'ATT1'
-  call flush_unit(stdout)
+  FLUSH(stdout)
   call  set_custom_grid(fc)
 
   call mp_barrier( world_comm )
   write(stdout,*) 'ATT2'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   call data_structure_custom(fc)
 
   call mp_barrier( world_comm )
   write(stdout,*) 'ATT3'
-  call flush_unit(stdout)
+  FLUSH(stdout)
   
   allocate(fc%nlt(fc%ngmt))
   allocate(fc%nltm(fc%ngmt))
   write(stdout,*) 'ATT4'
-  call flush_unit(stdout)
+  FLUSH(stdout)
   
   call ggent(fc)
   
@@ -695,7 +695,7 @@ SUBROUTINE ggent(fc)
    INTEGER, ALLOCATABLE :: igsrt(:)
    !
 
-#ifdef __PARA
+#ifdef __MPI
    INTEGER :: m1, m2, mc
    !
 #endif
@@ -764,7 +764,7 @@ SUBROUTINE ggent(fc)
       j = mill_g(2, ng)
       k = mill_g(3, ng)
 
-#ifdef __PARA
+#ifdef __MPI
       m1 = mod (i, fc%nr1t) + 1
       IF (m1 < 1) m1 = m1 + fc%nr1t
       m2 = mod (j, fc%nr2t) + 1
@@ -819,7 +819,7 @@ SUBROUTINE ggent(fc)
       IF (n1>fc%nr1t .or. n2>fc%nr2t .or. n3>fc%nr3t) &
          CALL errore('ggent','Mesh too small?',ng)
 
-#if defined (__PARA) && !defined (__USE_3D_FFT)
+#if defined (__MPI) && !defined (__USE_3D_FFT)
       fc%nlt (ng) = n3 + ( fc%dfftt%isind (n1 + (n2 - 1) * fc%nrx1t) - 1) * fc%nrx3t
 #else
       fc%nlt (ng) = n1 + (n2 - 1) * fc%nrx1t + (n3 - 1) * fc%nrx1t * fc%nrx2t
@@ -850,7 +850,7 @@ SUBROUTINE ggent(fc)
          CALL errore('ggent meno','Mesh too small?',ng)
       ENDIF
 
-#if defined (__PARA) && !defined (__USE_3D_FFT)
+#if defined (__MPI) && !defined (__USE_3D_FFT)
       fc%nltm(ng) = n3 + (fc%dfftt%isind (n1 + (n2 - 1) * fc%nrx1t) - 1) * fc%nrx3t
      
 #else
@@ -940,7 +940,7 @@ SUBROUTINE cft3t( fc, f, n1, n2, n3, nx1, nx2, nx3, sign )
   INTEGER,     INTENT(IN)    :: n1, n2, n3, nx1, nx2, nx3, sign
 
 
-#if defined (__PARA) && !defined(__USE_3D_FFT)
+#if defined (__MPI) && !defined(__USE_3D_FFT)
 !
   COMPLEX(DP), INTENT(INOUT) :: f( fc%dfftt%nnr )
   !
