@@ -22,7 +22,8 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
    USE gvect
    USE constants, ONLY : e2, pi, tpi, fpi
    USE cell_base, ONLY: at, alat, tpiba, omega, tpiba2
-   USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx, ecutwfc
+   USE wvfct,     ONLY : igk, npwx, npw, nbnd
+   USE gvecw,     ONLY : ecutwfc
    USE wavefunctions_module, ONLY : evc, psic
    USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
    USE mp_world, ONLY : world_comm, mpime, nproc
@@ -81,13 +82,13 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
    TYPE(fft_cus) :: fc
 
    write(stdout,*) 'Routine pola_basis_lanczos'
-   call flush_unit(stdout)
+   FLUSH(stdout)
 
    fc%ecutt=ecutwfc
    fc%dual_t=dual_vt
 
    if(l_verbose) write(stdout,*) 'Call initialize_fft_custom'
-   call flush_unit(stdout)
+   FLUSH(stdout)
    call initialize_fft_custom(fc)
    allocate(evc_g(fc%ngmt_g))
 
@@ -139,7 +140,7 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
   
 
    if(l_verbose) write(stdout,*) 'pola_basis_lanczos 1'
-   call flush_unit(stdout)
+   FLUSH(stdout)
    
 !now polarizability basis  are put on the ordering of the redueced grid, if required
   allocate(p_basis_t(fc%npwt,numpw))
@@ -214,14 +215,14 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
     !  allocate(tmp_r(fc%nrxxt))
 
          if(l_verbose) write(stdout,*) 'do fft'
-         call flush_unit(stdout)
+         FLUSH(stdout)
 
          do ii=1,numpw,2
 !!read n_set w^P'_i from disk
             if(.not.l_reduce_io) then
                call davcio(tmp_r,dfftp%nnr,iunrprod,ii,-1)
                write(stdout,*) 'ERROR l_reduce_io must be true'
-               call flush_unit(stdout)
+               FLUSH(stdout)
                stop
             endif
 
@@ -247,11 +248,11 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
             
          enddo
          if(l_verbose) write(stdout,*) 'do pc_operator'
-         call flush_unit(stdout)
+         FLUSH(stdout)
         call pc_operator_t_m(numpw,wp_prod(1,1,iv-ivv+1),evc_t,ispin, fc) 
 
          if(l_verbose) write(stdout,*) 'calculate omat'
-         call flush_unit(stdout)
+         FLUSH(stdout)
 
 
     
@@ -286,13 +287,13 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
 !!
       
      if(l_verbose)  write(stdout,*) 'solve eig'
-     call flush_unit(stdout)
+     FLUSH(stdout)
 
     
-      call flush_unit(stdout)
+      FLUSH(stdout)
       do iv=ivv,min(ivv+nbuf-1,num_nbndv(ispin))
          if(l_verbose) write(stdout,*) 'solve eig', iv
-         call flush_unit(stdout)
+         FLUSH(stdout)
          if(iv-ivv==mpime) then
             
             if(.not.l_dsyevr) then
@@ -313,16 +314,16 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
              !  do iw=1,numpw
              !     write(stdout,*) 'EIGEN:',iv,iw, eigen(iw)
              !  enddo
-             !  call flush_unit(stdout)
+             !  FLUSH(stdout)
             else
                if(l_verbose) write(stdout,*) 'ATT1'
-               call flush_unit(stdout)
+               FLUSH(stdout)
                allocate(eigen(numpw))
                allocate(vectors(numpw,nstates))
                allocate(isuppz(2*nstates))
                allocate(work(1),iwork(1))
                if(l_verbose)  write(stdout,*) 'ATT2'
-                call flush_unit(stdout)
+                FLUSH(stdout)
                call DSYEVR('V','I','U',numpw,omat_hold,numpw,0.d0,0.d0,numpw-nstates+1,numpw,0.d0,n_found,eigen,&
                     & vectors,numpw,isuppz,work, -1,iwork,-1, info)
                lwork=work(1)
@@ -331,7 +332,7 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
                allocate(work(lwork))
                allocate(iwork(liwork))
                if(l_verbose)  write(stdout,*) 'ATT3',numpw,nstates,size(omat_hold(:,1)),size(omat_hold(1,:)),lwork,liwork
-               call flush_unit(stdout)
+               FLUSH(stdout)
                vl=0.d0
                vu=0.d0
                il=numpw-nstates+1
@@ -343,14 +344,14 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
                   stop
                endif
                if(l_verbose)  write(stdout,*) 'ATT4'
-               call flush_unit(stdout)
+               FLUSH(stdout)
                deallocate(isuppz)
                deallocate(work,iwork)
         
                do iw=1,nstates,nstates-1
                   write(stdout,*) 'EIGEN T LOCAL:',iv,iw, eigen(iw)
                enddo
-               call flush_unit(stdout)
+               FLUSH(stdout)
 
             endif
       
@@ -358,7 +359,7 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
 !!find transformation matrix and write on disk
 !
         if(l_verbose) write(stdout,*) 'pola_basis_lanczos t_mat'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 
       
@@ -459,7 +460,7 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
 
 
         if(l_verbose) write(stdout,*) 'pola_basis update wp_g'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 
 !!find liner dependent products
@@ -472,12 +473,12 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
 
 
         if(l_verbose) write(stdout,*) 'pola_basis update wp_g dgemm'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
         call dgemm('N','N',2*fc%npwt,nstates,numpw,1.d0,wp_prod(1,1,iv-ivv+1),2*fc%npwt,t_mat,numpw,0.d0,wp_g_t,2*fc%npwt)
 
         write(stdout,*) 'pola_basis update merge-split',iv,ivv
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 !put the correct order
 
@@ -492,7 +493,7 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
            !enddo
         endif
         if(l_verbose) write(stdout,*) 'pola_basis update davcio',iv
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 
   !!write on disk
@@ -501,7 +502,7 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
         enddo
 
         if(l_verbose) write(stdout,*) 'pola_basis update done'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 
        
@@ -517,13 +518,13 @@ subroutine pola_basis_lanczos(n_set,nstates,numpw, nsteps,ispin)
   deallocate(t_eigen_hold)
   
   if(l_verbose) write(stdout,*) 'Exiting pola_basis_lanczos'
-  call flush_unit(stdout)
+  FLUSH(stdout)
    
   if(l_reduce_io) deallocate(p_basis)
   deallocate(p_basis_t,evc_t)
   
   if(l_verbose) write(stdout,*) 'Call deallocate_fft_custom'
-  call flush_unit(stdout)
+  FLUSH(stdout)
   deallocate(evc_g)
   call deallocate_fft_custom(fc)
    
@@ -539,7 +540,7 @@ subroutine pc_operator(state,ispin,l_cond)
    USE io_global,            ONLY : stdout
    USE kinds,    ONLY : DP
    USE gvect
-   USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx
+   USE wvfct,    ONLY : igk, npwx, npw, nbnd
    USE wavefunctions_module, ONLY : evc, psic
    USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
    USE mp_world, ONLY : world_comm
@@ -589,7 +590,7 @@ subroutine pc_operator_t(state,evc_t,ispin, fc)
    USE io_global,            ONLY : stdout
    USE kinds,    ONLY : DP
    USE gvect
-   USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx
+   USE wvfct,    ONLY : igk, npwx, npw, nbnd
    USE wavefunctions_module, ONLY : evc, psic
    USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
    USE mp_world, ONLY : world_comm
@@ -639,7 +640,7 @@ subroutine lanczos_state(zstates, nstates, itype, nsteps,istate,ispin)
   USE gvect
   USE constants, ONLY : e2, pi, tpi, fpi
   USE cell_base, ONLY: at, alat, tpiba, omega, tpiba2
-  USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx, ecutwfc
+  USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd
   USE wavefunctions_module, ONLY : evc, psic
   USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
   USE mp_world, ONLY : mpime, nproc, world_comm
@@ -748,7 +749,7 @@ subroutine lanczos_state(zstates, nstates, itype, nsteps,istate,ispin)
 
      
      write(stdout,*) 'lanczos_state:', istate,ispin
-     call flush_unit(stdout)
+     FLUSH(stdout)
 
      
 !calculate H|\phi_i>
@@ -805,7 +806,7 @@ subroutine lanczos_state(zstates, nstates, itype, nsteps,istate,ispin)
      call mp_sum(d(1,nbegin_ip:nend_ip), world_comm)
 
      if(l_verbose) write(stdout,*) 'Lanczos Diagonal 1', d(1,nbegin_ip:nend_ip)
-     call flush_unit(stdout)
+     FLUSH(stdout)
   
 !calculate f
 
@@ -819,7 +820,7 @@ subroutine lanczos_state(zstates, nstates, itype, nsteps,istate,ispin)
      call mp_sum(f(1,nbegin_ip:nend_ip), world_comm)
 
      if(l_verbose) write(stdout,*) 'ATTENZIONE1'
-     call flush_unit(stdout)
+     FLUSH(stdout)
 
 !calculate overlaps and write on output file
      if(omat_div) then
@@ -848,7 +849,7 @@ subroutine lanczos_state(zstates, nstates, itype, nsteps,istate,ispin)
            enddo
         endif
         if(l_verbose) write(stdout,*) 'ATTENZIONE2'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
         do ii=1,nstates
            call mp_sum(omat(:,ii), world_comm)
@@ -890,7 +891,7 @@ subroutine lanczos_state(zstates, nstates, itype, nsteps,istate,ispin)
      endif
   
      if(l_verbose) write(stdout,*) 'ATTENZIONE3'
-     call flush_unit(stdout)
+     FLUSH(stdout)
 
 
 !calculate second overlap
@@ -921,7 +922,7 @@ subroutine lanczos_state(zstates, nstates, itype, nsteps,istate,ispin)
            enddo
         endif
         if(l_verbose) write(stdout,*) 'ATTENZIONE4'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
         do ii=1,nstates
            call mp_sum(omat(:,ii), world_comm)
@@ -936,7 +937,7 @@ subroutine lanczos_state(zstates, nstates, itype, nsteps,istate,ispin)
 !do iterate
      do it=2,nsteps
         if(l_verbose) write(stdout,*) 'lanczos h_psi'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 !calculate H|\phi_i+1>
         call h_psi( npw, npw, nsize_ip,psi_2(1,1), u_1 )
@@ -944,7 +945,7 @@ subroutine lanczos_state(zstates, nstates, itype, nsteps,istate,ispin)
         if(l_scissor) call h_psi_scissor( ispin,npw, npw, nsize_ip,psi_2(1,1), u_1 )
 
         if(l_verbose) write(stdout,*) 'lanczos alfa beta gamma'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 
 
@@ -1000,7 +1001,7 @@ subroutine lanczos_state(zstates, nstates, itype, nsteps,istate,ispin)
         enddo
 
         if(l_verbose) write(stdout,*) 'lanczos d f omat'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 
 !calculate d
@@ -1141,7 +1142,7 @@ subroutine orthonormalize_two_manifolds( state1, n1,state2, n2, threshold, state
    USE io_global,            ONLY : stdout, ionode, ionode_id
    USE kinds,    ONLY : DP
    USE gvect
-   USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx
+   USE wvfct,    ONLY : igk, npwx, npw, nbnd
    USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
    USE mp_world, ONLY : world_comm
    USE fft_base,             ONLY : dfftp, dffts
@@ -1166,7 +1167,7 @@ subroutine orthonormalize_two_manifolds( state1, n1,state2, n2, threshold, state
  
 !buid overlap matrix
   if(l_verbose) write(stdout,*) 'orthonormalize dgemm'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   allocate(omat(n1+n2,n1+n2))
   omat(:,:)=0.d0
@@ -1183,13 +1184,13 @@ subroutine orthonormalize_two_manifolds( state1, n1,state2, n2, threshold, state
      enddo
   endif
   if(l_verbose) write(stdout,*) 'orthonormalize mp_sum'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   do ii=1,n2
      call mp_sum(tmp_mat(:,ii), world_comm)
   enddo
   if(l_verbose) write(stdout,*) 'orthonormalize copy array'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   omat(1:n1,n1+1:n1+n2)=tmp_mat(1:n1,1:n2)
   deallocate(tmp_mat)
@@ -1198,7 +1199,7 @@ subroutine orthonormalize_two_manifolds( state1, n1,state2, n2, threshold, state
 
    allocate(eigen(n1+n2))
    if(l_verbose) write(stdout,*) 'orthonormalize dsyev'
-   call flush_unit(stdout)
+   FLUSH(stdout)
   
    if(ionode) then
       allocate(work(1))
@@ -1217,7 +1218,7 @@ subroutine orthonormalize_two_manifolds( state1, n1,state2, n2, threshold, state
       omat(:,:)=0.d0
    endif
    if(l_verbose) write(stdout,*) 'orthonormalize mp_bcast now mp_sum'
-   call flush_unit(stdout)
+   FLUSH(stdout)
 
    do ii=1,n1+n2
       !call mp_bcast(omat(:,ii), ionode_id,world_comm)
@@ -1229,9 +1230,9 @@ subroutine orthonormalize_two_manifolds( state1, n1,state2, n2, threshold, state
    do ii=1,n1+n2
       if(l_verbose) write(stdout,*) 'EIGEN:',ii, eigen(ii)
    enddo
-   call flush_unit(stdout)
+   FLUSH(stdout)
    if(l_verbose) write(stdout,*) 'orthonormalize copy'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
 !construct orthonormal basis set 
  !  state_out(:,:)=(0.d0,0.d0)
@@ -1270,7 +1271,7 @@ subroutine orthonormalize_two_manifolds( state1, n1,state2, n2, threshold, state
 !   enddo
 
    write(stdout,*) 'orthonormalize_two_manifolds: basis dimension:', n_out
-   call flush_unit(stdout)
+   FLUSH(stdout)
 
   deallocate (omat)
   return
@@ -1286,7 +1287,7 @@ subroutine global_pola_lanczos(nstates,nstates_eff,threshold,nglobal,nsteps,nump
   USE kinds,    ONLY : DP
   USE wannier_gw, ONLY : num_nbndv,max_ngm,l_pmatrix
   USE gvect
-  USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx, ecutwfc
+  USE wvfct,    ONLY : igk, npwx, npw, nbnd
   USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
   USE mp_world, ONLY : world_comm
   USE wavefunctions_module, ONLY : evc, psic
@@ -1422,7 +1423,7 @@ subroutine global_pola_lanczos(nstates,nstates_eff,threshold,nglobal,nsteps,nump
 !!calculate basis
      nglobal_old=nglobal
      if(l_verbose) write(stdout,*) 'Call orthonormalize_two_manifolds'
-     call flush_unit(stdout)
+     FLUSH(stdout)
      if(.not.l_pmatrix) then
         !call orthonormalize_two_manifolds( old_basis, nglobal_old,v_basis, nstates, threshold, new_basis, nglobal)
         call orthonormalize_two_manifolds_prj( old_basis, nglobal_old,v_basis, nstates_eff, threshold, new_basis, nglobal,&
@@ -1431,7 +1432,7 @@ subroutine global_pola_lanczos(nstates,nstates_eff,threshold,nglobal,nsteps,nump
         call orthonormalize_two_manifolds_scalapack(old_basis, nglobal_old,v_basis, nstates_eff, threshold, new_basis, nglobal) 
      endif
      if(l_verbose) write(stdout,*) 'Done orthonormalize_two_manifolds',ispin
-     call flush_unit(stdout)
+     FLUSH(stdout)
 
 
 !!set arrays for next iteration
@@ -1494,10 +1495,10 @@ subroutine global_pola_lanczos(nstates,nstates_eff,threshold,nglobal,nsteps,nump
      deallocate(t_mat)
   if(l_test) then
      write(stdout,*) 'TEST1'
-     call flush_unit(stdout)
+     FLUSH(stdout)
      allocate(t_mat(nglobal,nglobal))
      write(stdout,*) 'TEST2'
-     call flush_unit(stdout)
+     FLUSH(stdout)
      
      call dgemm('T','N',nglobal,nglobal,2*npw,2.d0,old_basis,2*npw,old_basis,2*npw,0.d0,t_mat,nglobal)
      if(gstart==2) then
@@ -1508,7 +1509,7 @@ subroutine global_pola_lanczos(nstates,nstates_eff,threshold,nglobal,nsteps,nump
         enddo
      endif
      write(stdout,*) 'TEST3'
-     call flush_unit(stdout)
+     FLUSH(stdout)
 
      call mp_sum(t_mat(:,:), world_comm)
 !!write diagonal terms
@@ -1518,7 +1519,7 @@ subroutine global_pola_lanczos(nstates,nstates_eff,threshold,nglobal,nsteps,nump
            if(ii/=jj) sca=sca+abs(t_mat(ii,jj))
         enddo
         write(stdout,*) 'Diagonal',ii,t_mat(ii,ii),sca
-        call flush_unit(stdout)
+        FLUSH(stdout)
      enddo
      deallocate(t_mat)
      allocate(t_mat(nglobal,1))
@@ -1576,11 +1577,11 @@ subroutine global_pola_lanczos(nstates,nstates_eff,threshold,nglobal,nsteps,nump
 !         do ii=1,nglobal,50
 !            write(stdout,*) 'Q terms',iv,iw,ii, t_mat(ii,1)
 !         enddo
-           call flush_unit(stdout)
+           FLUSH(stdout)
         enddo
      enddo
      write(stdout,*) 'Average projection', proj_tot/dble(numpw*2)
-     call flush_unit(stdout)
+     FLUSH(stdout)
      deallocate(t_mat)
      deallocate(wv_real,tmp_g,tmp_r,wp_prod)
      close(iungprod)
@@ -1601,7 +1602,7 @@ subroutine orthonormalize_two_manifolds_scalapack( state1, n1,state2, n2, thresh
    USE io_global,            ONLY : stdout, ionode, ionode_id
    USE kinds,    ONLY : DP
    USE gvect
-   USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx
+   USE wvfct,    ONLY : igk, npwx, npw, nbnd
    USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
    USE mp_world, ONLY : world_comm
    USE wannier_gw, ONLY : p_mpime,p_nproc, npcol, nprow,icontxt,myrow,mycol
@@ -1657,7 +1658,7 @@ subroutine orthonormalize_two_manifolds_scalapack( state1, n1,state2, n2, thresh
 
   
   write(stdout,*) 'orthonormalize para1'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   do ii=1,n1
      do jj=1,n2
@@ -1707,7 +1708,7 @@ subroutine orthonormalize_two_manifolds_scalapack( state1, n1,state2, n2, thresh
   allocate(eigen(n))
 
   write(stdout,*) 'orthonormalize para2'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   call pdsyev('V','U',n,omat,1,1,desc_a,eigen,tmp_mat,1,1,desc_b,work,-1,info)
   lwork=work(1)
@@ -1721,12 +1722,12 @@ subroutine orthonormalize_two_manifolds_scalapack( state1, n1,state2, n2, thresh
   endif
    
   write(stdout,*) 'orthonormalize para3'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
    do ii=1,n,n
       write(stdout,*) 'EIGEN:',ii, eigen(ii)
    enddo
-   call flush_unit(stdout)
+   FLUSH(stdout)
 
 
    state_out(:,:)=(0.d0,0.d0)
@@ -1762,10 +1763,10 @@ subroutine orthonormalize_two_manifolds_scalapack( state1, n1,state2, n2, thresh
       endif
    enddo
    write(stdout,*) 'orthonormalize para4'
-   call flush_unit(stdout)
+   FLUSH(stdout)
 
    write(stdout,*) 'orthonormalize_two_manifolds: basis dimension:', n_out
-   call flush_unit(stdout)
+   FLUSH(stdout)
 
   deallocate (omat,tmp_mat,eigen)
 #endif
@@ -1781,7 +1782,7 @@ subroutine orthonormalize_two_manifolds_prj( state1, n1,state2, n2, threshold, s
    USE io_global,            ONLY : stdout, ionode, ionode_id
    USE kinds,    ONLY : DP
    USE gvect
-   USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx
+   USE wvfct,    ONLY : igk, npwx, npw, nbnd
    USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
    USE mp_world, ONLY : world_comm
    USE wannier_gw, ONLY : l_verbose
@@ -1809,7 +1810,7 @@ subroutine orthonormalize_two_manifolds_prj( state1, n1,state2, n2, threshold, s
 
 !buid overlap matrix
   if(l_verbose) write(stdout,*) 'orthonormalize dgemm'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   allocate(tmp_mat(n1,n2))
   call dgemm('T','N',n1,n2,2*npw,2.d0,state1,2*npw,state2,2*npw,0.d0,tmp_mat,n1)
@@ -1822,7 +1823,7 @@ subroutine orthonormalize_two_manifolds_prj( state1, n1,state2, n2, threshold, s
   endif
 
   if(l_verbose) write(stdout,*) 'orthonormalize mp_sum'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   do ii=1,n2
      call mp_sum(tmp_mat(:,ii), world_comm)
@@ -1852,7 +1853,7 @@ subroutine orthonormalize_two_manifolds_prj( state1, n1,state2, n2, threshold, s
   endif
 
   if(l_verbose) write(stdout,*) 'orthonormalize mp_sum'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
   do ii=1,n2
      call mp_sum(omat(:,ii), world_comm)
@@ -1863,7 +1864,7 @@ subroutine orthonormalize_two_manifolds_prj( state1, n1,state2, n2, threshold, s
 
    allocate(eigen(n2))
    if(l_verbose) write(stdout,*) 'orthonormalize dsyev'
-   call flush_unit(stdout)
+   FLUSH(stdout)
 
    if(ionode) then
       allocate(work(1))
@@ -1884,7 +1885,7 @@ subroutine orthonormalize_two_manifolds_prj( state1, n1,state2, n2, threshold, s
       omat(:,:)=0.d0
    endif
    if(l_verbose) write(stdout,*) 'orthonormalize mp_bcast now mp_sum'
-   call flush_unit(stdout)
+   FLUSH(stdout)
 
    do ii=1,n2
       !call mp_bcast(omat(:,ii), ionode_id,world_comm)
@@ -1897,9 +1898,9 @@ subroutine orthonormalize_two_manifolds_prj( state1, n1,state2, n2, threshold, s
    do ii=1,n2,n2-1
       write(stdout,*) 'EIGEN GLOBAL:',ii, eigen(ii)
    enddo
-   call flush_unit(stdout)
+   FLUSH(stdout)
    if(l_verbose) write(stdout,*) 'orthonormalize copy'
-  call flush_unit(stdout)
+  FLUSH(stdout)
 
 !construct orthonormal basis set
  !  state_out(:,:)=(0.d0,0.d0)
@@ -1924,7 +1925,7 @@ subroutine orthonormalize_two_manifolds_prj( state1, n1,state2, n2, threshold, s
    n_out=n_out+n1
 
    write(stdout,*) 'orthonormalize_two_manifolds: basis dimension:', n_out
-   call flush_unit(stdout)
+   FLUSH(stdout)
 
   deallocate (omat,eigen)
   return
@@ -1937,7 +1938,7 @@ subroutine pc_operator_test(state)
    USE io_global,            ONLY : stdout
    USE kinds,    ONLY : DP
    USE gvect
-   USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx
+   USE wvfct,    ONLY : igk, npwx, npw, nbnd
    USE wavefunctions_module, ONLY : evc, psic
    USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
    USE mp_world, ONLY : world_comm
@@ -1971,7 +1972,7 @@ subroutine pc_operator_t_m(numpw,state,evc_t,ispin,fc)
    USE io_global,            ONLY : stdout
    USE kinds,    ONLY : DP
    USE gvect
-   USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx
+   USE wvfct,    ONLY : igk, npwx, npw, nbnd
    USE wavefunctions_module, ONLY : evc, psic
    USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
    USE mp_world, ONLY : world_comm
@@ -2022,7 +2023,7 @@ subroutine pc_operator_t_r(numpw,state,evc_r,ispin,fc)
    USE io_global,            ONLY : stdout
    USE kinds,    ONLY : DP
    USE gvect
-   USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx
+   USE wvfct,    ONLY : igk, npwx, npw, nbnd
    USE wavefunctions_module, ONLY : evc, psic
    USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
    USE mp_world, ONLY : world_comm
@@ -2077,7 +2078,7 @@ subroutine  h_psi_self( lda, n, m, psi, hpsi )
   !
   USE kinds,    ONLY : DP
   USE gvect,    ONLY : gstart
-  USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx,et
+  USE wvfct,    ONLY : igk, npwx, npw, nbnd,et
   USE wavefunctions_module, ONLY : evc
   USE wannier_gw, ONLY : n_gw_states, ene_gw, delta_self
   USE mp, ONLY : mp_sum
@@ -2135,7 +2136,7 @@ subroutine  h_psi_scissor( ispin,lda, n, m, psi, hpsi )
 
   USE kinds,    ONLY : DP
   USE gvect,    ONLY : gstart
-  USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx,et
+  USE wvfct,    ONLY : igk, npwx, npw, nbnd,et
   USE wavefunctions_module, ONLY : evc
   USE wannier_gw, ONLY : num_nbndv,scissor
   USE mp, ONLY : mp_sum
@@ -2166,10 +2167,11 @@ subroutine  h_psi_scissor( ispin,lda, n, m, psi, hpsi )
 
   do jj=1,m
      do ii=1,num_nbndv(ispin)
-        prod(ii,jj)=prod(ii,jj)*scissor/rytoev
+        prod(ii,jj)=prod(ii,jj)*(scissor(1)-scissor(2))/rytoev
      enddo
   enddo
-  call dgemm('N','N',2*npw,m,num_nbndv(ispin),1.d0,evc,2*npwx,prod,num_nbndv(ispin),1.d0,hpsi,2*lda)
+  call dgemm('N','N',2*npw,m,num_nbndv(ispin),1.d0,evc,2*npwx,prod,num_nbndv(ispin),&
+       &1.d0+scissor(2)/rytoev,hpsi,2*lda)
 
 
   deallocate(prod)
@@ -2190,7 +2192,8 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
    USE gvect
    USE constants, ONLY : e2, pi, tpi, fpi
    USE cell_base, ONLY: at, alat, tpiba, omega, tpiba2
-   USE wvfct,    ONLY : igk, g2kin, npwx, npw, nbnd, nbndx, ecutwfc
+   USE wvfct,    ONLY : igk, npwx, npw, nbnd
+   USE gvecw,     ONLY : ecutwfc
    USE wavefunctions_module, ONLY : evc, psic
    USE mp, ONLY : mp_sum, mp_barrier, mp_bcast
    USE mp_pools, ONLY : intra_pool_comm
@@ -2251,13 +2254,13 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
    TYPE(fft_cus) :: fc
 
    write(stdout,*) 'Routine pola_basis_lanczos_real'
-   call flush_unit(stdout)
+   FLUSH(stdout)
 
    fc%ecutt=ecutwfc
    fc%dual_t=dual_vt
 
    if(l_verbose) write(stdout,*) 'Call initialize_fft_custom'
-   call flush_unit(stdout)
+   FLUSH(stdout)
    call initialize_fft_custom(fc)
 !   allocate(evc_g(fc%ngmt_g))
 !   allocate(wv_real(dfftp%nnr))
@@ -2291,7 +2294,7 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
   
 
    if(l_verbose) write(stdout,*) 'pola_basis_lanczos 1'
-   call flush_unit(stdout)
+   FLUSH(stdout)
    
 !now polarizability basis  are put on the ordering of the redueced grid, if required
   allocate(p_basis_t(fc%npwt,numpw))
@@ -2378,7 +2381,7 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
     !  allocate(tmp_r(fc%nrxxt))
 
          if(l_verbose) write(stdout,*) 'do fft',fc%nrxxt, numpw,iv-ivv+1
-         call flush_unit(stdout)
+         FLUSH(stdout)
          do ii=1,numpw
             wp_prod(1:fc%nrxxt, ii,iv-ivv+1)=p_basis_r(1:fc%nrxxt,ii)*wv_real(1:fc%nrxxt) 
          enddo
@@ -2387,7 +2390,7 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
          call pc_operator_t_r(numpw,wp_prod(1,1,iv-ivv+1),evc_r,ispin, fc)
 
          if(l_verbose) write(stdout,*) 'calculate omat'
-         call flush_unit(stdout)
+         FLUSH(stdout)
 
 
     
@@ -2416,13 +2419,13 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
 !!
       
      if(l_verbose)  write(stdout,*) 'solve eig'
-     call flush_unit(stdout)
+     FLUSH(stdout)
 
     
-      call flush_unit(stdout)
+      FLUSH(stdout)
       do iv=ivv,min(ivv+nbuf-1,num_nbndv(ispin))
          if(l_verbose) write(stdout,*) 'solve eig', iv
-         call flush_unit(stdout)
+         FLUSH(stdout)
          if(iv-ivv==mpime) then
             
             if(.not.l_dsyevr) then
@@ -2443,16 +2446,16 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
              !  do iw=1,numpw
              !     write(stdout,*) 'EIGEN:',iv,iw, eigen(iw)
              !  enddo
-             !  call flush_unit(stdout)
+             !  FLUSH(stdout)
             else
                if(l_verbose) write(stdout,*) 'ATT1'
-               call flush_unit(stdout)
+               FLUSH(stdout)
                allocate(eigen(numpw))
                allocate(vectors(numpw,nstates))
                allocate(isuppz(2*nstates))
                allocate(work(1),iwork(1))
                if(l_verbose)  write(stdout,*) 'ATT2'
-                call flush_unit(stdout)
+                FLUSH(stdout)
                call DSYEVR('V','I','U',numpw,omat_hold,numpw,0.d0,0.d0,numpw-nstates+1,numpw,0.d0,n_found,eigen,&
                     & vectors,numpw,isuppz,work, -1,iwork,-1, info)
                lwork=work(1)
@@ -2461,7 +2464,7 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
                allocate(work(lwork))
                allocate(iwork(liwork))
                if(l_verbose)  write(stdout,*) 'ATT3',numpw,nstates,size(omat_hold(:,1)),size(omat_hold(1,:)),lwork,liwork
-               call flush_unit(stdout)
+               FLUSH(stdout)
                vl=0.d0
                vu=0.d0
                il=numpw-nstates+1
@@ -2473,14 +2476,14 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
                   stop
                endif
                if(l_verbose)  write(stdout,*) 'ATT4'
-               call flush_unit(stdout)
+               FLUSH(stdout)
                deallocate(isuppz)
                deallocate(work,iwork)
         
                do iw=1,nstates
                   write(stdout,*) 'EIGEN:',iv,iw, eigen(iw)
                enddo
-               call flush_unit(stdout)
+               FLUSH(stdout)
 
             endif
       
@@ -2488,7 +2491,7 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
 !!find transformation matrix and write on disk
 !
         if(l_verbose) write(stdout,*) 'pola_basis_lanczos t_mat'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 
       
@@ -2593,7 +2596,7 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
 
 
         if(l_verbose) write(stdout,*) 'pola_basis update wp_g'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 
 !!find liner dependent products
@@ -2606,12 +2609,12 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
 
 
         if(l_verbose) write(stdout,*) 'pola_basis update wp_g dgemm'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
         call dgemm('N','N',fc%nrxxt,nstates,numpw,1.d0,wp_prod(1,1,iv-ivv+1),fc%nrxxt,t_mat,numpw,0.d0,wp_g_t,fc%nrxxt)
 
         write(stdout,*) 'pola_basis update merge-split',iv,ivv
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 !put the correct order
        
@@ -2653,7 +2656,7 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
 
         deallocate(wp_g_t2)
         if(l_verbose) write(stdout,*) 'pola_basis update davcio',iv
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 
   !!write on disk
@@ -2662,7 +2665,7 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
         enddo
 
         if(l_verbose) write(stdout,*) 'pola_basis update done'
-        call flush_unit(stdout)
+        FLUSH(stdout)
 
 
        
@@ -2679,13 +2682,13 @@ subroutine pola_basis_lanczos_real(n_set,nstates,numpw, nsteps,ispin)
   deallocate(t_eigen_hold)
   
   if(l_verbose) write(stdout,*) 'Exiting pola_basis_lanczos'
-  call flush_unit(stdout)
+  FLUSH(stdout)
    
   deallocate(p_basis)
   deallocate(p_basis_t,evc_t)
   
   if(l_verbose) write(stdout,*) 'Call deallocate_fft_custom'
-  call flush_unit(stdout)
+  FLUSH(stdout)
   !deallocate(evc_g)
   call deallocate_fft_custom(fc)
    
